==> igloo_0_1_8.zip: igloo_0_1_8/igloo/language/1/barnraiser_01/lib_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_library_item'] = 					"wiki page";
$lang['hdr_history'] = 							"recent history";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";
$lang['href_wiki_first_page'] = 				"start your library";
$lang['href_item_comments_only'] = 				"Show only the comment against this version of this page";
$lang['href_all_comments'] = 					"Show all comments associated with this page";
$lang['href_add_library'] = 					"add wiki page";
$lang['href_contents'] = 						"contents";
$lang['href_view_firstpage'] = 					"first page";
$lang['href_view_contents'] = 					"contents";
$lang['href_my_library'] = 						"my wiki pages";
$lang['href_marked'] = 							"marked wiki pages";


// ERROR
$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"This wiki page has been tagged with";
$lang['txt_item_tag'] = 						"This wiki page is tagged with with";
$lang['txt_view'] = 							"view";
$lang['txt_options'] = 							"options";
$lang['txt_intro_contents'] = 					"Listed are the wiki pages that have been published by members of this community.";
$lang['txt_intro_history'] = 					"Listed is the history of this wiki page.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"wiki";

?>

==> igloo_0_1_9.zip: igloo_0_1_9/igloo/language/1/barnraiser_01/lib_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_library'] = 							"wiki";
$lang['hdr_library_items'] = 					"wiki pages";
$lang['hdr_library_item'] = 					"wiki page";
$lang['hdr_history'] = 							"recent history";


//A HREF TAGS (links)
$lang['href_edit_library'] = 					"edit this";
$lang['href_doc_history'] =						"see wiki page history";
$lang['href_default'] = 						"first page";
$lang['href_view_latest'] = 					"view latest version";
$lang['href_wiki_first_page'] = 				"start your library";
$lang['href_item_comments_only'] = 				"Show only the comment against this version of this page";
$lang['href_all_comments'] = 					"Show all comments associated with this page";
$lang['href_add_library'] = 					"add wiki page";
$lang['href_contents'] = 						"contents";
$lang['href_view_firstpage'] = 					"first page";
$lang['href_view_contents'] = 					"contents";
$lang['href_my_library'] = 						"my wiki pages";
$lang['href_marked'] = 							"marked wiki pages";
$lang['href_tipped'] = 							"tipped wiki pages";


// ERROR
$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_version_lastest'] = 					"This is the latest version of this wiki page.";
$lang['txt_version_old'] = 						"This is an OLD version of this wiki page.";
$lang['txt_page_name'] = 						"wiki page name";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag_intro'] = 						"This wiki page has been tagged with";
$lang['txt_item_tag'] = 						"This wiki page is tagged with with";
$lang['txt_view'] = 							"view";
$lang['txt_options'] = 							"options";
$lang['txt_intro_contents'] = 					"Listed are the wiki pages that have been published by members of this community.";
$lang['txt_intro_history'] = 					"Listed is the history of this wiki page.";
$lang['txt_intro_marked'] = 					"You have bookmarked the following items for reading. You can manage your bookmarks under 'Me', 'marks &amp; tips'.";
$lang['txt_intro_tipped'] = 					"Your network have recommended (tipped) the following items for reading. You can manage your recommendations to your network under 'Me', 'marks &amp; tips'.";
$lang['txt_tag'] = 								"tags";

// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"wiki";

?>
